import React, { Component } from 'react';
import HeaderBar from '@/common/HeaderBar'
import './video.scss'
import { NavLink, Route } from 'react-router-dom';
import { http, api } from '@/utils'
import Recommendation from './recommendation'
import VideoCatalog from './video-catalog'
import DatumCatalog from './datum-catalog'
import { Toast } from 'antd-mobile';


class Video extends Component {

    state = {
        title: '视频',
        courseId: 140,
        video_catalog: [],
        datum: []
    }


    componentDidMount() {
        this.getVideoCatalog()
        this.getDatumCatalog()
    }


    getVideoCatalog = () => {
        http.get(`${api.home}/m/course/play/40`)
            .then(res => {
                const data = res.data
                if (data.code === 200) {

                    this.setState({
                        video_catalog: data.data.lessons
                    })


                } else {
                    Toast.info(data.msg)
                }
            })
    }


    getDatumCatalog() {
        http.get(`${api.home}/m/course/data/40`)
            .then(res => {
                const data = res.data
                if (data.code === 200) {

                    this.setState({
                        datum: data.data
                    })

                } else {
                    Toast.info(data.msg)
                }
            })
    }


    render() {
        let {match} = this.props
        return (
            <div className='play'>
                <HeaderBar title={this.state.title}/>
                <div className="video">
                </div>
                <div className='tab'>
                    <div>
                        <NavLink to={`${match.url}/video`}
                                 replace
                                 activeClassName='active'
                        >视频</NavLink>
                    </div>
                    <div>
                        <NavLink to={`${match.url}/datum`}
                                 replace
                                 activeClassName='active'
                        >资料</NavLink>
                    </div>
                </div>
                <Route path={`${match.path}/video`} render={props => {
                    return <VideoCatalog videoCatalog={this.state.video_catalog} {...props}/>
                }}/>
                <Route path={`${match.path}/datum`} render={props => {
                    return <DatumCatalog {...props} datum={this.state.datum}/>
                }}/>
                <Route render={props => {
                    return <Recommendation {...props} courseId={this.state.courseId}/>
                }}/>
            </div>
        );
    }
}


export default Video;